<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>QObject</name>
    <message>
        <location filename="../qsynthSetup.cpp" line="37"/>
        <source>(default)</source>
        <translation>(výchozí)</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="168"/>
        <source>Usage: %1 [options] [soundfonts] [midifiles]</source>
        <translation>Použití: %1 [volby] [zvuková písma] [soubory MIDI]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="171"/>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="173"/>
        <source>Don&apos;t create a midi driver to read MIDI input events [default = yes]</source>
        <translation>Nevytvářet žádný ovladač MIDI kvůli čtení vstupních událostí MIDI [výchozí = yes]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="175"/>
        <source>The name of the midi driver to use [oss,alsa,alsa_seq,...]</source>
        <translation>Název používaného ovladače MIDI [oss, alsa, alsa_seq,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="177"/>
        <source>The number of midi channels [default = 16]</source>
        <translation>Počet kanálů MIDIe [výchozí = 16]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="179"/>
        <source>The audio driver [alsa,jack,oss,dsound,...]</source>
        <translation>Zvukový ovladač [alsa, jack, oss, dsound,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="181"/>
        <source>Attempt to connect the jack outputs to the physical ports</source>
        <translation>Pokusit se spojit výstupy JACK s fyzickými přípojkami</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="183"/>
        <source>The number of stereo audio channels [default = 1]</source>
        <translation>Počet stereo zvukových kanálů [výchozí = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="185"/>
        <source>The number of audio groups [default = 1]</source>
        <translation>Počet zvukových skupin [výchozí = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="187"/>
        <source>Size of each audio buffer</source>
        <translation>Velikost zvukové vyrovnávací paměti</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="189"/>
        <source>Number of audio buffers</source>
        <translation>Počet zvukových vyrovnávacích pamětí</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="191"/>
        <source>Set the sample rate</source>
        <translation>Nastavit vzorkovací kmitočet</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="193"/>
        <source>Turn the reverb on or off [1|0|yes|no|on|off, default = on]</source>
        <translation>Zapnout nebo vypnout dozvuk [[1|0|yes|no|on|off, výchozí = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="195"/>
        <source>Turn the chorus on or off [1|0|yes|no|on|off, default = on]</source>
        <translation>Zapnout nebo vypnout sbor [[1|0|yes|no|on|off, Voreinstellung = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="197"/>
        <source>Set the master gain [0 &lt; gain &lt; 10, default = 0.2]</source>
        <translation>Nastavit výstupní zesílení [0 &lt; zesílení &lt; 10, výchozí = 0.2]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="199"/>
        <source>Define a setting name=value</source>
        <translation>Stanovit nastavení název=hodnota</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="201"/>
        <source>Create and start server [default = no]</source>
        <translation>Vytvořit a spustit server [výchozí = ne]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="203"/>
        <source>Don&apos;t read commands from the shell [ignored]</source>
        <translation>Nečíst příkazyze shellu [nebráno na vědomí]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="205"/>
        <source>Dump midi router events</source>
        <translation>Vytisknout události směrovače MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="207"/>
        <source>Print out verbose messages about midi events</source>
        <translation>Vytisknout podrobná hlášení o událostech MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="209"/>
        <source>Show help about command line options</source>
        <translation>Ukázat nápovědu k argumentům příkazového řádku</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="211"/>
        <source>Show version information</source>
        <translation>Ukázat informaci o verzi</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="243"/>
        <source>Option -m requires an argument (midi-driver).</source>
        <translation>Volba -m potřebuje argument (midi-driver).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="252"/>
        <source>Option -K requires an argument (midi-channels).</source>
        <translation>Volba -K potřebuje argument (midi-channels).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="261"/>
        <source>Option -a requires an argument (audio-driver).</source>
        <translation>Volba -a potřebuje argument (audio-driver).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="273"/>
        <source>Option -L requires an argument (audio-channels).</source>
        <translation>Volba -L potřebuje argument (audio-channels).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="282"/>
        <source>Option -G requires an argument (audio-groups).</source>
        <translation>Volba -G potřebuje argument (audio-groups).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="291"/>
        <source>Option -z requires an argument (audio-bufsize).</source>
        <translation>Volba -z potřebuje aArgument (audio-bufsize).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="300"/>
        <source>Option -c requires an argument (audio-bufcount).</source>
        <translation>Volba -c potřebuje argument (audio-bufcount).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="309"/>
        <source>Option -r requires an argument (sample-rate).</source>
        <translation>Volba -r potřebuje argument (sample-rate).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="336"/>
        <source>Option -g requires an argument (gain).</source>
        <translation>Volba -g potřebuje argument (gain).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="345"/>
        <source>Option -o requires an argument.</source>
        <translation>Volba -o potřebuje argument.</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="367"/>
        <source>Qt: %1
</source>
        <translation>Qt: %1
</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="385"/>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>Neznámá volba: &apos;%1&apos;.</translation>
    </message>
</context>
<context>
    <name>qsynthAboutForm</name>
    <message>
        <location filename="../qsynthAboutForm.ui" line="33"/>
        <source>About Qsynth</source>
        <translation>O Qsynthu</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="61"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="71"/>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="43"/>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="44"/>
        <source>Build</source>
        <translation>Sestavení</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="47"/>
        <source>Debugging option enabled.</source>
        <translation>Povolena možnost ladění.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="53"/>
        <source>System tray disabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="58"/>
        <source>Server option disabled.</source>
        <translation>Zakázána možnost serveru.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="64"/>
        <source>System reset option disabled.</source>
        <translation>Zakázána možnost znovunastavení systému.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="70"/>
        <source>Bank offset option disabled.</source>
        <translation>Zakázána možnost polohy banky.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="75"/>
        <source>Website</source>
        <translation>Internetová stránka</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="80"/>
        <source>This program is free software; you can redistribute it and/or modify it</source>
        <translation>Tento program je svobodným software; Můžete jej rozšiřovat a/nebo upravovat</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="81"/>
        <source>under the terms of the GNU General Public License version 2 or later.</source>
        <translation>za podmínek GNU General Public License.</translation>
    </message>
</context>
<context>
    <name>qsynthChannelsForm</name>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="36"/>
        <source>Qsynth: Channels</source>
        <translation>Qsynth: Kanály</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="56"/>
        <source>Preset &amp;Name:</source>
        <translation>&amp;Název přednastavení:</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="77"/>
        <source>Settings preset name</source>
        <translation>Název přednastavení nastavení</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="84"/>
        <source>(default)</source>
        <translation>(výchozí)</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="92"/>
        <source>Save settings as current preset name</source>
        <translation>Uložit nastavení pod nynějším názvem přednastavení</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="95"/>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="108"/>
        <source>Delete current settings preset</source>
        <translation>Smazat nynější přednastavení nastavení</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="111"/>
        <source>&amp;Delete</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="143"/>
        <source>Channels view</source>
        <translation>Pohled na kanály</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="168"/>
        <source>In</source>
        <translation>Vstup</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="173"/>
        <source>Chan</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="178"/>
        <source>Bank</source>
        <translation>Banka</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="183"/>
        <source>Prog</source>
        <translation>Prog</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="188"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="193"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="198"/>
        <source>Soundfont</source>
        <translation>Zvukové písmo</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="172"/>
        <source>Channels</source>
        <translation>Kanály</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="333"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="338"/>
        <source>Unset</source>
        <translation>Odložit</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="342"/>
        <source>Refresh</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="470"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="471"/>
        <source>Delete preset:</source>
        <translation>Smazat přednastavení:</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="473"/>
        <source>Are you sure?</source>
        <translation>Jste si jistý?</translation>
    </message>
</context>
<context>
    <name>qsynthMainForm</name>
    <message>
        <location filename="../qsynthMainForm.ui" line="34"/>
        <source>Qsynth - A fluidsynth Qt GUI Interface</source>
        <translation>Qsynth - Na Qt založené uživatelské rozhraní pro fluidsynth</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1019"/>
        <source>Add a new engine</source>
        <translation>Přidat nový zvukový modul</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1032"/>
        <source>Engine selector (right-click for menu)</source>
        <translation>Vybrat zvukový modul (pravým klepnutím v nabídce)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1070"/>
        <source>Delete current engine</source>
        <translation>Smazat nynější zvukový modul</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="977"/>
        <source>Show/hide the channels view window</source>
        <translation>Ukázat/Skrýt okno s pohledem na kanály</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="980"/>
        <location filename="../qsynthMainForm.cpp" line="1111"/>
        <source>&amp;Channels</source>
        <translation>&amp;Kanály</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="130"/>
        <source>Complete engine restart</source>
        <translation>Zvukový modul spustit úplně znovu</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="133"/>
        <location filename="../qsynthMainForm.cpp" line="1102"/>
        <location filename="../qsynthMainForm.cpp" line="1198"/>
        <source>Re&amp;start</source>
        <translation>&amp;Spustit znovu</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="948"/>
        <source>Program reset (all channels)</source>
        <translation>Nastavit znovu program (všechny kanály)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="951"/>
        <location filename="../qsynthMainForm.cpp" line="1104"/>
        <source>&amp;Reset</source>
        <translation>&amp;Nastavit znovu</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="961"/>
        <source>Show instance settings and configuration dialog</source>
        <translation>Ukázat dialog nastavení s nynějším nastavením</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="964"/>
        <location filename="../qsynthMainForm.cpp" line="1116"/>
        <location filename="../qsynthMainForm.cpp" line="1594"/>
        <source>Set&amp;up...</source>
        <translation>&amp;Nastavení...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="49"/>
        <source>Master</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="67"/>
        <source>&amp;Gain</source>
        <translation>&amp;Zesílení</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="89"/>
        <location filename="../qsynthMainForm.ui" line="114"/>
        <source>Master Gain</source>
        <translation>Nastavení zesílení pro výstupní signál</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="935"/>
        <source>System reset</source>
        <translation>Znovunastavit systém</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="938"/>
        <location filename="../qsynthMainForm.cpp" line="1107"/>
        <source>&amp;Panic</source>
        <translation>&amp;Panika</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="149"/>
        <source>Reverb</source>
        <translation>Dozvuk</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="173"/>
        <source>Reverb effect activation</source>
        <translation>Spustit efekt dozvuku</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="176"/>
        <source>Ac&amp;tive</source>
        <translation>&amp;Spuštěný</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="189"/>
        <location filename="../qsynthMainForm.ui" line="208"/>
        <source>Reverb Level</source>
        <translation>Síla dozvuku</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="233"/>
        <source>&amp;Level</source>
        <translation>&amp;Síla</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="255"/>
        <location filename="../qsynthMainForm.ui" line="296"/>
        <source>Reverb Width</source>
        <translation>Vzdálenost ke zdroji zvuku (poloměr dozvuku)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="274"/>
        <source>&amp;Width</source>
        <translation>&amp;Vzdálenost</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="321"/>
        <location filename="../qsynthMainForm.ui" line="362"/>
        <source>Reverb Damp Factor</source>
        <translation>Tlumení dozvuku</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="340"/>
        <source>D&amp;amp</source>
        <translation>&amp;Tlumení</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="387"/>
        <location filename="../qsynthMainForm.ui" line="428"/>
        <source>Reverb Room Size</source>
        <translation>Velikost prostorui dozvuku</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="406"/>
        <source>R&amp;oom</source>
        <translation>&amp;Prostor</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="456"/>
        <source>Chorus</source>
        <translation>Sbor</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="480"/>
        <source>Chorus Modulation Type</source>
        <translation>Typ obměňování sboru</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="484"/>
        <source>Sine</source>
        <translation>Sinus</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="489"/>
        <source>Triangle</source>
        <translation>Trojúhelník</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="509"/>
        <source>T&amp;ype:</source>
        <translation>&amp;Typ:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="537"/>
        <source>Chorus effect activation</source>
        <translation>Spuštění efektu sboru</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="540"/>
        <source>Act&amp;ive</source>
        <translation>&amp;Spuštěný</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="553"/>
        <location filename="../qsynthMainForm.ui" line="600"/>
        <source>Number of Chorus Stages</source>
        <translation>Počet sborových hlasů</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="578"/>
        <source>&amp;N</source>
        <translation>&amp;Hlasy</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="619"/>
        <location filename="../qsynthMainForm.ui" line="666"/>
        <source>Chorus Level</source>
        <translation>Síla sboru</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="644"/>
        <source>Le&amp;vel</source>
        <translation>&amp;Síla</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="685"/>
        <location filename="../qsynthMainForm.ui" line="738"/>
        <source>Chorus Speed (Hz)</source>
        <translation>Rychlost obměňování sboru (Hz)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="713"/>
        <source>Chorus Speed Hz</source>
        <translation>Rychlost obměňování sboru Hz</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="716"/>
        <source>Spee&amp;d</source>
        <translation>&amp;Rychlost</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="760"/>
        <location filename="../qsynthMainForm.ui" line="807"/>
        <source>Chorus Depth (ms)</source>
        <translation>Hloubka sboru - čas oddělení hlasu (ms)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="785"/>
        <source>Dept&amp;h</source>
        <translation>&amp;Hloubka - čas oddělení</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="832"/>
        <source>Output peak level</source>
        <translation>Ukazatel výstupní hladiny</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="850"/>
        <source>Quit this application</source>
        <translation>Ukončit tento program</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="853"/>
        <location filename="../qsynthMainForm.cpp" line="1148"/>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="866"/>
        <source>Show general options dialog</source>
        <translation>Ukázat dialog pro všeobecné volby</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="869"/>
        <location filename="../qsynthMainForm.cpp" line="1142"/>
        <source>&amp;Options...</source>
        <translation>&amp;Volby...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="882"/>
        <source>Show/hide the messages log window</source>
        <translation>Ukázat/Skrýt okno se zápisy hlášení</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="885"/>
        <location filename="../qsynthMainForm.cpp" line="1138"/>
        <source>&amp;Messages</source>
        <translation>&amp;Hlášení</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="901"/>
        <source>Show information about this application</source>
        <translation>Ukázat informace o tomto programu</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="904"/>
        <source>A&amp;bout...</source>
        <translation>&amp;O...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="662"/>
        <location filename="../qsynthMainForm.cpp" line="1485"/>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="664"/>
        <source>The program will keep running in the system tray.

To terminate the program, please choose &quot;Quit&quot;
in the context menu of the system tray icon.</source>
        <translation>Program poběží dále v oznamovací oblasti panelu.

Pro ukončení programu vyberte, prosím, &quot;Ukončit&quot;
v související nabídce vyskakující z ikony v oznamovací
oblasti panelu.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="680"/>
        <source>Don&apos;t show this message again</source>
        <translation>Toto hlášení neukazovat znovu</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="702"/>
        <location filename="../qsynthMainForm.cpp" line="1309"/>
        <location filename="../qsynthMainForm.cpp" line="2061"/>
        <location filename="../qsynthMainForm.cpp" line="2090"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="704"/>
        <source>is about to terminate.</source>
        <translation>má být ukončen.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="705"/>
        <location filename="../qsynthMainForm.cpp" line="1312"/>
        <source>Are you sure?</source>
        <translation>Jste si jistý?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="715"/>
        <source>Don&apos;t ask this again</source>
        <translation>Neptat se znovu</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="795"/>
        <source>Loading soundfont: &quot;%1&quot;</source>
        <translation>Nahrává se zvukové písmo: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="806"/>
        <location filename="../qsynthMainForm.cpp" line="1764"/>
        <source>Failed to load the soundfont: &quot;%1&quot;.</source>
        <translation>Nahrávání zvukového písma se nezdařilo: &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="814"/>
        <source>Playing MIDI file: &quot;%1&quot;</source>
        <translation>Přehrává se soubor MIDI: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="821"/>
        <source>Failed to play MIDI file: &quot;%1&quot;.</source>
        <translation>Přehrávání souboru MIDI se nezdařilo: &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="981"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1084"/>
        <source>&amp;Hide</source>
        <translation>&amp;Skrýt</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1080"/>
        <source>Mi&amp;nimize</source>
        <translation>&amp;Zmenšit</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1085"/>
        <source>S&amp;how</source>
        <translation>&amp;Ukázat</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1081"/>
        <source>Rest&amp;ore</source>
        <translation>&amp;Obnovit</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1094"/>
        <location filename="../qsynthMainForm.cpp" line="1588"/>
        <source>&amp;New engine...</source>
        <translation>&amp;Nový zvukový modul...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1096"/>
        <location filename="../qsynthMainForm.cpp" line="1590"/>
        <source>&amp;Delete</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1102"/>
        <location filename="../qsynthMainForm.cpp" line="1200"/>
        <source>&amp;Start</source>
        <translation>&amp;Spustit</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1122"/>
        <source>Engines</source>
        <translation>Zvukové moduly</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1310"/>
        <source>Delete fluidsynth engine:</source>
        <translation>Smazat fluidsynthový zvukový modul:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1487"/>
        <source>Some settings will be only effective
next time you start this program.</source>
        <translation>Některá nastavení začnou působit
až po novém spuštění programu.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1724"/>
        <source>Creating synthesizer engine</source>
        <translation>Vytváří se syntetizátorový zvukový modul</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1727"/>
        <source>Failed to create the synthesizer.

Cannot continue without it.</source>
        <translation>Syntetizátorový zvukový modul se nepodařilo vytvořit.

Bez něj nelze pokračovat.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1758"/>
        <source>Loading soundfont: &quot;%1&quot; (bank offset %2)</source>
        <translation>Nahrává se zvukové písmo: &quot;%1&quot; (poloha banky %2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1771"/>
        <source>Failed to set bank offset (%1) for soundfont: &quot;%2&quot;.</source>
        <translation>Nastavení hodnoty polohy banky (%1) pro zvukové písmo: &quot;%2&quot; se nepodařilo.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1781"/>
        <source>Creating audio driver (%1)</source>
        <translation>Vytváří se zvukový ovladač (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1795"/>
        <source>Failed to create the audio driver (%1).

Cannot continue without it.</source>
        <translation>Zvukový ovladač (%1) se vytvořit nepodařilo.

Bez něj nelze pokračovat.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1808"/>
        <source>Creating MIDI router (%1)</source>
        <translation>Vytváří se směrovač MIDI (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1817"/>
        <source>Failed to create the MIDI input router (%1).

No MIDI input will be available.</source>
        <translation>Směrovač vstupu MIDI (%1) se vytvořit nepodařilo.

Nebude dostupný žádný MIDI vstup.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1823"/>
        <source>Creating MIDI driver (%1)</source>
        <translation>Vytváří se ovladač MIDI (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1832"/>
        <source>Failed to create the MIDI driver (%1).

No MIDI input will be available.</source>
        <translation>Ovladač MIDI (%1) se vytvořit nepodařilo.

Nebude dostupný žádný MIDI vstup.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1839"/>
        <source>Creating MIDI player</source>
        <translation>Vytváří se přehrávač MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1843"/>
        <source>Failed to create the MIDI player.

Continuing without a player.</source>
        <translation>Přehrávač MIDI se vytvořit nepodařilo.

Pokračuje se bez přehrávače.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1853"/>
        <source>Creating server</source>
        <translation>Vytváří se server</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1875"/>
        <source>Failed to create the server.

Continuing without it.</source>
        <translation>Server se vytvořit nepodařilo.

Pokračuje se bez něj.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1879"/>
        <source>Server mode disabled.

Continuing without it.</source>
        <translation>Režim serveru zakázán.

Pokračuje se bez něj.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1913"/>
        <source>Synthesizer engine started.</source>
        <translation>Syntetizátorový zvukový modul spuštěn.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1953"/>
        <source>Destroying server</source>
        <translation>Vypíná se server</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1961"/>
        <source>Stopping MIDI player</source>
        <translation>Zastavuje se přehrávač MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1963"/>
        <source>Waiting for MIDI player to terminate</source>
        <translation>Čeká se na ukončení přehrávače MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1965"/>
        <source>Destroying MIDI player</source>
        <translation>Vypíná se přehrávač MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1973"/>
        <source>Destroying MIDI driver</source>
        <translation>Vypíná se ovladač MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1977"/>
        <source>Destroying MIDI router</source>
        <translation>Vypíná se směrovač MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1984"/>
        <source>Destroying audio driver</source>
        <translation>Vypíná se zvukový ovladač</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1999"/>
        <source>Unloading soundfont: &quot;%1&quot; (SFID=%2)</source>
        <translation>Vyjímá se zvukové písmo: &quot;%1&quot; (SFID=%2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2003"/>
        <source>Failed to unload the soundfont: &quot;%1&quot;.</source>
        <translation>Vyjmutí zvukového písma: &quot;%1&quot; se nezdařilo.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2010"/>
        <source>Destroying synthesizer engine</source>
        <translation>Vypíná se syntetizátorový zvukový modul</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2014"/>
        <source>Synthesizer engine terminated.</source>
        <translation>Syntetizátorový zvukový modul ukončen.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2062"/>
        <source>New settings will be effective after
restarting all fluidsynth engines.</source>
        <translation>Nová nastavení začnou působit až po novém spuštění
všech fluidsynthových zvukových modulů.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2064"/>
        <location filename="../qsynthMainForm.cpp" line="2094"/>
        <source>Please note that this operation may cause
temporary MIDI and Audio disruption.</source>
        <translation>Všimněte si, prosím, že toto nové spuštění bude mít
za následek dočasné přerušení MIDI a Audia.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2066"/>
        <source>Do you want to restart all engines now?</source>
        <translation>Chtěl byste nyní spustit všechny zvukové moduly znovu?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2091"/>
        <source>New settings will be effective after
restarting the fluidsynth engine:</source>
        <translation>Nová nastavení začnou působit až po novém spuštění
fluidsynthovéhoh zvukového modulu:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2096"/>
        <source>Do you want to restart the engine now?</source>
        <translation>Chtěl byste nyní spustit zvukový modul znovu?</translation>
    </message>
</context>
<context>
    <name>qsynthMessagesForm</name>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="42"/>
        <source>Qsynth: Messages</source>
        <translation>Qsynth: Hlášení</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="54"/>
        <source>Messages output log</source>
        <translation>Historie zaznamenaných hlášení</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="136"/>
        <source>Logging stopped --- %1 ---</source>
        <translation>Zaznamenávání zastaveno --- %1 ---</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="146"/>
        <source>Logging started --- %1 ---</source>
        <translation>Zaznamenávání spuštěno --- %1 ---</translation>
    </message>
</context>
<context>
    <name>qsynthOptionsForm</name>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="33"/>
        <source>Qsynth: Options</source>
        <translation>Qsynth: Volby</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="43"/>
        <source>Display</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="55"/>
        <source>Messages</source>
        <translation>Hlášení</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="82"/>
        <source>Sample messages text font display</source>
        <translation>Písmo pro okno s hlášeními</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="110"/>
        <source>Select font for the messages text display</source>
        <translation>Vybrat písmo pro okno s hlášeními</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="113"/>
        <source>&amp;Font...</source>
        <translation>&amp;Písmo...</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="145"/>
        <source>Whether to keep a maximum number of lines in the messages window</source>
        <translation>Omezit nejvyšší počet ukázaných řádků hlášení</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="148"/>
        <source>&amp;Messages limit:</source>
        <translation>&amp;Nejvyšší počet hlášení:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="161"/>
        <source>The maximum number of message lines to keep in view</source>
        <translation>Nejvyšší počet ukázaných řádků hlášení</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="171"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="176"/>
        <source>250</source>
        <translation>250</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="181"/>
        <source>500</source>
        <translation>500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="186"/>
        <source>1000</source>
        <translation>1000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="191"/>
        <source>2500</source>
        <translation>2500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="196"/>
        <source>5000</source>
        <translation>5000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="213"/>
        <source>Logging</source>
        <translation>Přihlášení</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="236"/>
        <source>Messages log file</source>
        <translation>Soubor se zápisem hlášení</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="267"/>
        <source>Browse for the messages log file location</source>
        <translation>Hledat umístění souboru se zápisem hlášení</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="270"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="283"/>
        <source>Whether to activate a messages logging to file.</source>
        <translation>Hlášení zapisovat do souboru.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="440"/>
        <source>Other</source>
        <translation>Další</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="455"/>
        <source>Whether to ask for confirmation on application exit</source>
        <translation>Při ukončení aplikace žádat o potvrzení</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="458"/>
        <source>&amp;Confirm application close</source>
        <translation>&amp;Potvrdit zavření aplikace</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="471"/>
        <source>Whether to keep all child windows on top of the main window</source>
        <translation>Všechna podokna rozmístit nad hlavním oknem</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="474"/>
        <source>&amp;Keep child windows always on top</source>
        <translation>Podokna &amp;rozmístit vždy nad hlavním oknem</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="487"/>
        <source>Whether to capture standard output (stdout/stderr) into messages window</source>
        <translation>Standardní výstup (stdout/stderr) převádět do hlavního okna</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="490"/>
        <source>Capture standard &amp;output</source>
        <translation>Standardní výstup &amp;převést</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="503"/>
        <source>Whether to monitor and show engine output peak level meters</source>
        <translation>Sledovat a ukazovat nástroj výstupní hladiny</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="506"/>
        <source>Output &amp;peak level meters</source>
        <translation>Ukazovat &amp;nástroj výstupní hladiny</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="532"/>
        <source>Whether to enable the system tray icon</source>
        <translation>V oznamovací oblasti panelu ukazovat symbol aplikace</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="535"/>
        <source>&amp;Enable system tray icon</source>
        <translation>S&amp;ymbol aplikace ukazovat v oznamovací oblasti panelu</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="239"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="240"/>
        <source>Some options have been changed.</source>
        <translation>Některá nastavení byla změněna.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="241"/>
        <source>Do you want to apply the changes?</source>
        <translation>Chtěl byste použít změny?</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="299"/>
        <source>Messages Log</source>
        <translation>Zápis hlášení</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="301"/>
        <source>Log files</source>
        <translation>Soubory se zápisy</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="302"/>
        <source>Knobs</source>
        <translation>Otočný regulátor</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="333"/>
        <source>Graphic style for knobs</source>
        <translation>Obrazový styl točných regulátorů</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="337"/>
        <source>Classic</source>
        <translation>Klasický</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="342"/>
        <source>Vokimon</source>
        <translation>Vokimon</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="347"/>
        <source>Peppino</source>
        <translation>Peppino</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="357"/>
        <location filename="../qsynthOptionsForm.ui" line="413"/>
        <source>Legacy</source>
        <translation>Dědictví</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="406"/>
        <source>Mouse motion behavior for knobs</source>
        <translation>Odezva otočného regulátoru na pohyb myši</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="418"/>
        <source>Radial</source>
        <translation>Paprskovitý</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="423"/>
        <source>Linear</source>
        <translation>Přímočarý</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="548"/>
        <source>Whether to show system tray message on main window close</source>
        <translation>Ukázat zprávu v oznamovací oblasti panelu při zavření hlavního okna</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="551"/>
        <source>Sho&amp;w system tray message on close</source>
        <translation>&amp;Ukázat zprávu v oznamovací oblasti panelu při zavření</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="583"/>
        <source>Defaults</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="620"/>
        <source>&amp;Base font size:</source>
        <translation>Základní velikost &amp;písma:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="639"/>
        <source>Base application font size (pt.)</source>
        <translation>Základní velikost písma v aplikaci (v bodech)</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="646"/>
        <source>(default)</source>
        <translation>(výchozí)</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="661"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="666"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="671"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="676"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="681"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="286"/>
        <source>Messages &amp;log file:</source>
        <translation>Soubor se &amp;zápisem hlášení:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="317"/>
        <source>Kno&amp;b graphic style:</source>
        <translation>Obrazový styl točných &amp;regulátorů:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="387"/>
        <source>Mouse motion be&amp;havior:</source>
        <translation>Odezva otočného regulátoru na po&amp;hyb myši:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="651"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="656"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="352"/>
        <source>Skulpture</source>
        <translation>Skulpture</translation>
    </message>
</context>
<context>
    <name>qsynthPresetForm</name>
    <message>
        <location filename="../qsynthPresetForm.ui" line="33"/>
        <source>Qsynth: Channel Preset</source>
        <translation>Qsynth: Přednastavení kanálů</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="59"/>
        <source>Preset</source>
        <translation>Přednastavení</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="87"/>
        <source>Bank selector</source>
        <translation>Přepínač banky</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="112"/>
        <source>Bank</source>
        <translation>Banka</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="118"/>
        <source>Program selector</source>
        <translation>Přepínač programu</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="143"/>
        <source>Prog</source>
        <translation>Prog</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="148"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="153"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="158"/>
        <source>Soundfont</source>
        <translation>Zvukové písmo</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="167"/>
        <source>Whether to preview the current selection</source>
        <translation>Ukázat náhled nynějšího výběru</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="170"/>
        <source>Preview</source>
        <translation>Náhled</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.cpp" line="147"/>
        <source>Channel %1</source>
        <translation>Kanál %1</translation>
    </message>
</context>
<context>
    <name>qsynthSetupForm</name>
    <message>
        <location filename="../qsynthSetupForm.ui" line="34"/>
        <source>Qsynth: Setup</source>
        <translation>Qsynth: Nachystání</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="51"/>
        <source>Engine &amp;Name:</source>
        <translation>&amp;Název zvukového modulu:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="64"/>
        <source>Engine display name</source>
        <translation>Zobrazený název zvukového modulu</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="93"/>
        <source>&amp;MIDI</source>
        <translation>&amp;MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="131"/>
        <location filename="../qsynthSetupForm.ui" line="685"/>
        <source>MIDI device name</source>
        <translation>Název zařízení MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="161"/>
        <source>MIDI &amp;Device:</source>
        <translation>&amp;Zařízení MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="99"/>
        <source>&amp;MIDI Driver:</source>
        <translation>&amp;Ovladač MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="151"/>
        <source>Input MIDI driver</source>
        <translation>Ovladač pro vstup MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="283"/>
        <source>MIDI Client Name ID (ALSA/CoreMidi):</source>
        <translation>ID názvu klienta MIDI (ALSA/CoreMidi):</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="296"/>
        <source>ALSA Sequencer client name identification</source>
        <translation>ID názvu klienta u ALSA sequenceru</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="303"/>
        <source>pid</source>
        <translation>pid</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="308"/>
        <location filename="../qsynthSetupForm.ui" line="781"/>
        <source>qsynth</source>
        <translation>qsynth</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="115"/>
        <source>Whether to show MIDI router events on messages window</source>
        <translation>Ukázat události směrovače MIDI v okně hlášení</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="118"/>
        <source>&amp;Dump MIDI router events</source>
        <translation>&amp;Vytisknout události směrovače MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="177"/>
        <source>Print out verbose messages about MIDI events</source>
        <translation>Vytisknout podrobná hlášení o událostech MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="180"/>
        <source>&amp;Verbose MIDI event messages</source>
        <translation>&amp;Podrobná hlášení o událostech MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="203"/>
        <source>Number of MIDI channels</source>
        <translation>Počet kanálů MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="190"/>
        <source>MIDI &amp;Channels:</source>
        <translation>&amp;Kanály MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="141"/>
        <source>Enable MIDI input</source>
        <translation>Spustit vstup MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="144"/>
        <source>Enable MIDI &amp;Input</source>
        <translation>Spustit &amp;vstup MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="236"/>
        <source>gm</source>
        <translation>gm</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="241"/>
        <source>gs</source>
        <translation>gs</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="246"/>
        <source>mma</source>
        <translation>mma</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="251"/>
        <source>xs</source>
        <translation>xs</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="219"/>
        <source>MIDI &amp;Bank Select mode:</source>
        <translation>Režim výběru &amp;banky MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="229"/>
        <source>MIDI Bank Select mode</source>
        <translation>Režim výběru banky MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="358"/>
        <source>&amp;Audio</source>
        <translation>&amp;Zvuk</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="382"/>
        <source>Sample &amp;Format:</source>
        <translation>Vzorkovací &amp;formát (rozlišení):</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="395"/>
        <source>Output audio driver</source>
        <translation>Ovladač zvuku pro výstup</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="405"/>
        <source>Sample format</source>
        <translation>Vzorkovací formát - Číselný formát zdigitalizovaného zvukového signálu</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="412"/>
        <source>Period size in bytes (audio buffer size)</source>
        <translation>Velikost periody (velikost zvukové vyrovnávací paměti) v bytech</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="419"/>
        <location filename="../qsynthSetupForm.ui" line="564"/>
        <source>64</source>
        <translation>64</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="424"/>
        <source>128</source>
        <translation>128</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="429"/>
        <source>256</source>
        <translation>256</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="434"/>
        <source>512</source>
        <translation>512</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="439"/>
        <source>1024</source>
        <translation>1024</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="444"/>
        <source>2048</source>
        <translation>2048</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="449"/>
        <source>4096</source>
        <translation>4096</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="454"/>
        <source>8192</source>
        <translation>8192</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="462"/>
        <source>Buffer Cou&amp;nt:</source>
        <translation>&amp;Množství vyrovnávací paměti:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="475"/>
        <source>Sample rate in samples per second (Hz)</source>
        <translation>Vzorkovací kmitočet ve vzorcích za sekundu (Hz)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="485"/>
        <source>22050</source>
        <translation>22050</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="490"/>
        <source>44100</source>
        <translation>44100</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="495"/>
        <source>48000</source>
        <translation>48000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="500"/>
        <source>88200</source>
        <translation>88200</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="505"/>
        <source>96000</source>
        <translation>96000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="519"/>
        <source>Sample &amp;Rate:</source>
        <translation>Vzorkovací &amp;kmitočet:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="532"/>
        <source>Period count (number of audio buffers)</source>
        <translation>Počet period (počet zvukových vyrovnávacích pamětí)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="539"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="544"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="549"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="554"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="559"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="572"/>
        <source>Buffer &amp;Size:</source>
        <translation>&amp;Velikost vyrovnávací paměti:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="585"/>
        <source>&amp;Audio Driver:</source>
        <translation>&amp;Zvukový ovladač:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="605"/>
        <source>Audio &amp;Device:</source>
        <translation>Zvukové &amp;zařízení:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="624"/>
        <source>Audio &amp;Channels:</source>
        <translation>Zvukové &amp;kanály:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="637"/>
        <source>Number of audio groups</source>
        <translation>Počet zvukových skupin</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="650"/>
        <source>Number of enabled polyphonic voices</source>
        <translation>Počet povolených vícehlasých hlasů</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="666"/>
        <source>Number of stereo audio channels</source>
        <translation>Počet stereo zvukových kanálů</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="698"/>
        <source>&amp;Polyphony:</source>
        <translation>&amp;Vícehlas:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="727"/>
        <source>Audio &amp;Groups:</source>
        <translation>Zvukové &amp;skupiny:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="753"/>
        <source>JACK Client Name &amp;ID:</source>
        <translation>&amp;ID názvu klienta JACK:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="766"/>
        <source>JACK client name identification</source>
        <translation>Identifikátor názvu klienta JACK</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="776"/>
        <source>fluidsynth</source>
        <translation>fluidsynth</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="804"/>
        <source>Attempt to connect the JACK outputs to the physical ports</source>
        <translation>Pokusit se spojit výstupy JACK s fyzickými přípojkami</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="807"/>
        <source>Auto Connect &amp;JACK Outputs</source>
        <translation>Automaticky spojit výstupy &amp;JACK</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="814"/>
        <source>Create multiple JACK output ports for channels, groups and effects</source>
        <translation>Vytvořit více připojení výstupů JACK pro kanály, skupiny a efekty</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="817"/>
        <source>&amp;Multiple JACK Outputs</source>
        <translation>&amp;Více výstupů JACK</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="841"/>
        <source>&amp;Soundfonts</source>
        <translation>&amp;Zvuková písma</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="856"/>
        <source>Soundfont stack</source>
        <translation>Zásobník zvukových písem</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="878"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="883"/>
        <location filename="../qsynthSetupForm.ui" line="1025"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="888"/>
        <source>Offset</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="901"/>
        <source>Open soundfont file for loading</source>
        <translation>Otevřít soubor se zvukovým písmem pro nahrání</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="904"/>
        <source>&amp;Open...</source>
        <translation>&amp;Otevřít...</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="914"/>
        <source>Edit selected soundfont bank offset</source>
        <translation>Upravit hodnotu polohy vybrané banky se zvukovým písmem</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="917"/>
        <source>&amp;Edit</source>
        <translation>&amp;Úpravy</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="927"/>
        <source>Remove selected soundfont from stack</source>
        <translation>Odstranit vybrané zvukové písmo ze zásobníku</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="930"/>
        <source>&amp;Remove</source>
        <translation>&amp;Odstranit</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="953"/>
        <source>Move up selected soundfont towards the top of stack</source>
        <translation>Vybrané zvukové písmo přesunout v zásobníku nahoru</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="956"/>
        <source>&amp;Up</source>
        <translation>&amp;Nahoru</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="966"/>
        <source>Move down selected soundfont towards the bottom of stack</source>
        <translation>Vybrané zvukové písmo přesunout v zásobníku dolů</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="969"/>
        <source>&amp;Down</source>
        <translation>&amp;Dolů</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="982"/>
        <source>S&amp;ettings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1030"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1035"/>
        <source>Realtime</source>
        <translation>Prováděný v reálném čase</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1040"/>
        <source>Current</source>
        <translation>Nynější</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1045"/>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1050"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1055"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1060"/>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="362"/>
        <source>Setup</source>
        <translation>Nachystat</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="573"/>
        <location filename="../qsynthSetupForm.cpp" line="832"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="574"/>
        <source>Some settings have been changed.</source>
        <translation>Některá nastavení byla změněna.</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="575"/>
        <source>Do you want to apply the changes?</source>
        <translation>Chtěl byste použít změny?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="770"/>
        <source>Open...</source>
        <translation>Otevřít...</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="775"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="780"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="785"/>
        <source>Move Up</source>
        <translation>Přesunout nahoru</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="789"/>
        <source>Move Down</source>
        <translation>Přesunout dolů</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="815"/>
        <location filename="../qsynthSetupForm.cpp" line="817"/>
        <source>Soundfont files</source>
        <translation>Soubory se zvukovými písmy</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="833"/>
        <source>Soundfont file already on list</source>
        <translation>Soubor se zvukovým písmem je již součástí seznamu</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="835"/>
        <source>Add anyway?</source>
        <translation>Přesto přidat?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="862"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="863"/>
        <source>Failed to add soundfont file</source>
        <translation>Nepodařilo se přidat soubor se zvukovým písmem</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="865"/>
        <source>Please, check for a valid soundfont file.</source>
        <translation>Zvolte, prosím, platný soubor se zvukovým písmem.</translation>
    </message>
</context>
</TS>
